==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QQuickFramebufferObject_Renderer_shell.h <==
#ifndef QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H
#define QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtQuick/qquickframebufferobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtGui/qopenglframebufferobject.h>
#include <QtJambi/RegistryAPI>


class QQuickFramebufferObject$Renderer_shell : public QQuickFramebufferObject::Renderer, public QtJambiShellInterface
{
public:
    QQuickFramebufferObject$Renderer_shell();
    ~QQuickFramebufferObject$Renderer_shell() override;

    QOpenGLFramebufferObject* createFramebufferObject(const QSize& size0) override;
    void render() override;
    void synchronize(QQuickFramebufferObject* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickFramebufferObject$Renderer_access : public QQuickFramebufferObject::Renderer
{
    jobject __qt_framebufferObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_invalidateFramebufferObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_createFramebufferObject_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0);
    void __qt_render(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_synchronize_QQuickFramebufferObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.7.jar: sources/QtJambiQuick/QQuickFramebufferObject_Renderer_shell.h <==
#ifndef QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H
#define QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtQuick/qquickframebufferobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtOpenGL/qopenglframebufferobject.h>
#include <QtJambi/RegistryAPI>


class QQuickFramebufferObject$Renderer_shell : public QQuickFramebufferObject::Renderer, public QtJambiShellInterface
{
public:
    QQuickFramebufferObject$Renderer_shell();
    ~QQuickFramebufferObject$Renderer_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickFramebufferObject$Renderer_oshell;
};


class QQuickFramebufferObject$Renderer_oshell : public QQuickFramebufferObject$Renderer_shell
{
public:
    using QQuickFramebufferObject$Renderer_shell::QQuickFramebufferObject$Renderer_shell;
    QOpenGLFramebufferObject* createFramebufferObject(const QSize& size0) override;
    void render() override;
    void synchronize(QQuickFramebufferObject* arg__1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickFramebufferObject$Renderer_access : public QQuickFramebufferObject::Renderer
{
    jobject __qt_framebufferObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_invalidateFramebufferObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_createFramebufferObject_cref_QSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0);
    void __qt_render(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_synchronize_QQuickFramebufferObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QQUICKFRAMEBUFFEROBJECT_RENDERER_SHELL_H
